==> ejc-outcontract-impl-3.0.0-20220315.061656-64-sources.jar: com/ejianc/foundation/outcontract/bean/OutcontractEquipmentRentEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租金明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outcontract_equipment_rent")
public class OutcontractEquipmentRentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="outcontract_id")
    private Long outcontractId; // 合同id
    @TableField(value="equipment_id")
    private Long equipmentId; // 物资id
    @TableField(value="equipment_category_id")
    private Long equipmentCategoryId; // 物资分类id
    @TableField(value="equipment_category_name")
    private String equipmentCategoryName; // 物资分类名称
    @TableField(value="equipment_code")
    private String equipmentCode; // 物资编码
    @TableField(value="equipment_name")
    private String equipmentName; // 物资名称
    @TableField(value="equipment_spec")
    private String equipmentSpec; // 规格型号
    @TableField(value="equipment_unit")
    private String equipmentUnit; // 计量单位
    @TableField(value="quantity")
    private Integer quantity; // 台数
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="lease_term")
    private BigDecimal leaseTerm; // 租赁期（天）
    @TableField(value="untax_unit_price")
    private BigDecimal untaxUnitPrice; // 不含税单价
    @TableField(value="tax_unit_price")
    private BigDecimal taxUnitPrice; // 含税单价
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-outcontract-impl-3.0.0-20250915.113811-287-sources.jar: com/ejianc/foundation/outcontract/bean/OutcontractEquipmentRentEntity.java <==
package com.ejianc.foundation.outcontract.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 租金明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outcontract_equipment_rent")
public class OutcontractEquipmentRentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="outcontract_id")
    private Long outcontractId; // 合同id
    @TableField(value="equipment_id")
    private Long equipmentId; // 物资id
    @TableField(value="equipment_category_id")
    private Long equipmentCategoryId; // 物资分类id
    @TableField(value="equipment_category_name")
    private String equipmentCategoryName; // 物资分类名称
    @TableField(value="equipment_category_code")
    private String equipmentCategoryCode; // 物资分类编码
    @TableField(value="equipment_code")
    private String equipmentCode; // 物资编码
    @TableField(value="equipment_name")
    private String equipmentName; // 物资名称
    @TableField(value="equipment_spec")
    private String equipmentSpec; // 规格型号
    @TableField(value="equipment_unit")
    private String equipmentUnit; // 计量单位
    @TableField(value="quantity")
    private Integer quantity; // 台数
    @TableField(value="tax_rate")
    private BigDecimal taxRate; // 税率（%）
    @TableField(value="total_price")
    private BigDecimal totalPrice; // 合价
    @TableField(value="lease_term")
    private BigDecimal leaseTerm; // 租赁期（天）
    @TableField(value="untax_unit_price")
    private BigDecimal untaxUnitPrice; // 不含税单价
    @TableField(value="tax_unit_price")
    private BigDecimal taxUnitPrice; // 含税单价
    @TableField(value="remark")
    private String remark; // 备注
    
    
    

    public Long getOutcontractId() {
        return outcontractId;
    }

    public void setOutcontractId(Long outcontractId) {
        this.outcontractId = outcontractId;
    }
    public Long getEquipmentId() {
        return equipmentId;
    }

    public void setEquipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public Long getEquipmentCategoryId() {
        return equipmentCategoryId;
    }

    public void setEquipmentCategoryId(Long equipmentCategoryId) {
        this.equipmentCategoryId = equipmentCategoryId;
    }
    public String getEquipmentCategoryName() {
        return equipmentCategoryName;
    }

    public void setEquipmentCategoryName(String equipmentCategoryName) {
        this.equipmentCategoryName = equipmentCategoryName;
    }
    public String getEquipmentCode() {
        return equipmentCode;
    }

    public void setEquipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getEquipmentSpec() {
        return equipmentSpec;
    }

    public void setEquipmentSpec(String equipmentSpec) {
        this.equipmentSpec = equipmentSpec;
    }
    public String getEquipmentUnit() {
        return equipmentUnit;
    }

    public void setEquipmentUnit(String equipmentUnit) {
        this.equipmentUnit = equipmentUnit;
    }
    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(BigDecimal totalPrice) {
        this.totalPrice = totalPrice;
    }
    public BigDecimal getLeaseTerm() {
        return leaseTerm;
    }

    public void setLeaseTerm(BigDecimal leaseTerm) {
        this.leaseTerm = leaseTerm;
    }
    public BigDecimal getUntaxUnitPrice() {
        return untaxUnitPrice;
    }

    public void setUntaxUnitPrice(BigDecimal untaxUnitPrice) {
        this.untaxUnitPrice = untaxUnitPrice;
    }
    public BigDecimal getTaxUnitPrice() {
        return taxUnitPrice;
    }

    public void setTaxUnitPrice(BigDecimal taxUnitPrice) {
        this.taxUnitPrice = taxUnitPrice;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

	public String getEquipmentCategoryCode() {
		return equipmentCategoryCode;
	}

	public void setEquipmentCategoryCode(String equipmentCategoryCode) {
		this.equipmentCategoryCode = equipmentCategoryCode;
	}
    
}
